@@ -6,7 +6,11 @@ from __future__ import absolute_import
 from ..base_component import Selector
 from .base_control import BaseControl
 from selenium.webdriver.common.by import By
+from selenium.webdriver.common.keys import Keys
 from .button import Button
+import platform
+
+os_base = platform.system()
 
 class Message(BaseControl):
     """
@@ -19,12 +23,9 @@ class Message(BaseControl):
         """
         super(Message, self).__init__(browser, container)  
         self.elements.update({
-            "msg_text": Selector(select=container.select + " .msg-text"),
-            "msg_close": Selector(select=container.select + " .close")
+            "msg_text": Selector(select=container.select + '[data-test="message"]'),
         })
 
-
-
     def get_msg(self):
         '''
         Returns the error message
@@ -32,15 +33,6 @@ class Message(BaseControl):
         '''
         return self.msg_text.text.strip()
 
-    def close_msg(self):
-        """
-        Cancel the error message 
-            :return: Bool if successful
-        """
-        self.wait_to_be_clickable("msg_close")
-        self.msg_close.click()
-        return True
-
     def wait_loading(self):
         """
         Wait till the message appears and then dissapears
@@ -59,4 +51,3 @@ class Message(BaseControl):
             :return: Str The text message after appearing
         """
         return self.container.text.strip()
-        
